{-# LANGUAGE CPP #-}
#define PLATFORM_NAME   Windows
#define IS_WINDOWS      1
#include "Include.hs"
